@@ -1,4 +1,5 @@
 from functools import partial
+from operator import getitem
 
 import numpy as np
 
@@ -48,6 +49,7 @@ class Aggregator:
         types=None,
     ):
         self.name = name
+        self._initval_orig = initval
         self._initval = False if initval is None else initval
         self._initdtype = lookup_dtype(type(self._initval))
         self._monoid = monoid
@@ -67,9 +69,22 @@ class Aggregator:
                 initval = self._initval
             else:  # pragma: no cover
                 raise TypeError("types must be provided for composite and custom aggregators")
-        self.types = _get_types(types, None if initval is None else self._initdtype)
+        self._types_orig = types
+        self._types = None
         self._typed_ops = {}
 
+    @property
+    def types(self):
+        if self._types is None:
+            if type(self._semiring) is str:
+                self._semiring = semiring.from_string(self._semiring)
+                if type(self._types_orig[0]) is str:  # pragma: no branch
+                    self._types_orig[0] = semiring.from_string(self._types_orig[0])
+            self._types = _get_types(
+                self._types_orig, None if self._initval_orig is None else self._initdtype
+            )
+        return self._types
+
     def __getitem__(self, dtype):
         dtype = _normalize_type(dtype)
         if dtype not in self.types:
@@ -85,6 +100,9 @@ class Aggregator:
     def __repr__(self):
         return f"agg.{self.name}"
 
+    def __reduce__(self):
+        return f"agg.{self.name}"
+
 
 class TypedAggregator:
     opclass = "Aggregator"
@@ -231,6 +249,9 @@ class TypedAggregator:
         else:
             raise NotImplementedError(f"{agg.name} with {expr.cfunc_name}")
 
+    def __reduce__(self):
+        return (getitem, (self.parent, self.type))
+
 
 # Monoid-only
 agg.sum = Aggregator("sum", monoid=monoid.plus)
@@ -294,9 +315,9 @@ agg.logaddexp2 = Aggregator(
 # hypot = Aggregator('hypot', monoid=semiring.numpy.hypot)
 
 agg.L0norm = agg.count_nonzero
-agg.L1norm = Aggregator("L1norm", semiring=semiring.plus_absfirst, semiring2=semiring.plus_first)
+agg.L1norm = Aggregator("L1norm", semiring="plus_absfirst", semiring2=semiring.plus_first)
 agg.L2norm = agg.hypot
-agg.Linfnorm = Aggregator("Linfnorm", semiring=semiring.max_absfirst, semiring2=semiring.max_first)
+agg.Linfnorm = Aggregator("Linfnorm", semiring="max_absfirst", semiring2=semiring.max_first)
 
 
 # Composite
