@@ -25,6 +25,7 @@ scalar = {
     "__float__",
     "__index__",
     "__int__",
+    "__invert__",
     "__neg__",
     "is_empty",
     "value",
@@ -61,13 +62,11 @@ matrix = {
     "mxv",
     "reduce_columns",
     "reduce_rows",
+    "reduce_columnwise",
+    "reduce_rowwise",
     "reduce_scalar",
 }
-common_raises = {
-    "__ior__",
-    "__iand__",
-    "__imatmul__",
-}
+common_raises = set()
 scalar_raises = {
     "__and__",
     "__matmul__",
@@ -92,6 +91,10 @@ bad_sugar = {
     "__ipow__",
     "__isub__",
     "__itruediv__",
+    "__ixor__",
+    "__ior__",
+    "__iand__",
+    "__imatmul__",
 }
 # Copy the result of this below
 for name in sorted(common | scalar | vector_matrix | vector | matrix):
@@ -230,6 +233,10 @@ def __int__(self):
     return self._get_value("__int__")
 
 
+def __invert__(self):
+    return self._get_value("__invert__")
+
+
 def __iter__(self):
     return self._get_value("__iter__")
 
@@ -334,10 +341,18 @@ def reduce_columns(self):
     return self._get_value("reduce_columns")
 
 
+def reduce_columnwise(self):
+    return self._get_value("reduce_columnwise")
+
+
 def reduce_rows(self):
     return self._get_value("reduce_rows")
 
 
+def reduce_rowwise(self):
+    return self._get_value("reduce_rowwise")
+
+
 def reduce_scalar(self):
     return self._get_value("reduce_scalar")
 
@@ -370,10 +385,18 @@ def __iadd__(self, other):
     raise TypeError(f"'__iadd__' not supported for {type(self).__name__}")
 
 
+def __iand__(self, other):
+    raise TypeError(f"'__iand__' not supported for {type(self).__name__}")
+
+
 def __ifloordiv__(self, other):
     raise TypeError(f"'__ifloordiv__' not supported for {type(self).__name__}")
 
 
+def __imatmul__(self, other):
+    raise TypeError(f"'__imatmul__' not supported for {type(self).__name__}")
+
+
 def __imod__(self, other):
     raise TypeError(f"'__imod__' not supported for {type(self).__name__}")
 
@@ -382,6 +405,10 @@ def __imul__(self, other):
     raise TypeError(f"'__imul__' not supported for {type(self).__name__}")
 
 
+def __ior__(self, other):
+    raise TypeError(f"'__ior__' not supported for {type(self).__name__}")
+
+
 def __ipow__(self, other):
     raise TypeError(f"'__ipow__' not supported for {type(self).__name__}")
 
@@ -392,3 +419,7 @@ def __isub__(self, other):
 
 def __itruediv__(self, other):
     raise TypeError(f"'__itruediv__' not supported for {type(self).__name__}")
+
+
+def __ixor__(self, other):
+    raise TypeError(f"'__ixor__' not supported for {type(self).__name__}")
