@@ -21,7 +21,7 @@ from .utils import (
     values_to_numpy_buffer,
     wrapdoc,
 )
-from .vector import Vector, VectorExpression, _VectorAsMatrix
+from .vector import Vector, VectorExpression
 
 ffi_new = ffi.new
 
@@ -32,11 +32,12 @@ class Matrix(BaseType):
     High-level wrapper around GrB_Matrix type
     """
 
-    __slots__ = "_nrows", "_ncols", "ss"
+    __slots__ = "_nrows", "_ncols", "_parent", "ss"
+    ndim = 2
     _is_transposed = False
     _name_counter = itertools.count()
 
-    def __init__(self, gb_obj, dtype, *, name=None):
+    def __init__(self, gb_obj, dtype, *, parent=None, name=None):
         if name is None:
             name = f"M_{next(Matrix._name_counter)}"
         self._nrows = None
@@ -44,8 +45,12 @@ class Matrix(BaseType):
         super().__init__(gb_obj, dtype, name)
         # Add ss extension methods
         self.ss = ss(self)
+        self._parent = parent
 
     def __del__(self):
+        parent = getattr(self, "_parent", None)
+        if parent is not None:
+            return
         gb_obj = getattr(self, "gb_obj", None)
         if gb_obj is not None:
             # it's difficult/dangerous to record the call, b/c `self.name` may not exist
@@ -58,12 +63,20 @@ class Matrix(BaseType):
         with skip_record:
             return format_matrix(self, mask=mask)
 
-    def _repr_html_(self, mask=None):
+    def _repr_html_(self, mask=None, collapse=False):
+        if self._parent is not None:
+            return self._parent._repr_html_(mask=mask, collapse=collapse)
         from .formatting import format_matrix_html
         from .recorder import skip_record
 
         with skip_record:
-            return format_matrix_html(self, mask=mask)
+            return format_matrix_html(self, mask=mask, collapse=collapse)
+
+    @property
+    def _name_html(self):
+        if self._parent is not None:
+            return self._parent._name_html
+        return super()._name_html
 
     def __reduce__(self):
         # SS, SuiteSparse-specific: export
@@ -90,8 +103,8 @@ class Matrix(BaseType):
         resolved_indexes = IndexerResolver(self, keys)
         return AmbiguousAssignOrExtract(self, resolved_indexes)
 
-    def __setitem__(self, keys, delayed):
-        Updater(self)[keys] = delayed
+    def __setitem__(self, keys, expr):
+        Updater(self)[keys] = expr
 
     def __contains__(self, index):
         extractor = self[index]
@@ -307,7 +320,11 @@ class Matrix(BaseType):
         to use by multiple threads.  Use wait to force completion of a Matrix
         and make it safe to use as input parameters on multiple threads.
         """
-        call("GrB_Matrix_wait", [_Pointer(self)])
+        # TODO: expose COMPLETE or MATERIALIZE options to the user
+        call(
+            "GrB_Matrix_wait",
+            [self, Scalar.from_value(lib.GrB_MATERIALIZE, name="GrB_MATERIALIZE")],
+        )
 
     @classmethod
     def new(cls, dtype, nrows=0, ncols=0, *, name=None):
@@ -406,7 +423,11 @@ class Matrix(BaseType):
         """
         method_name = "ewise_add"
         other = self._expect_type(
-            other, (Matrix, TransposedMatrix), within=method_name, argname="other"
+            other,
+            (Matrix, TransposedMatrix),
+            within=method_name,
+            argname="other",
+            op=op,
         )
         op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
         # Per the spec, op may be a semiring, but this is weird, so don't.
@@ -442,7 +463,7 @@ class Matrix(BaseType):
         """
         method_name = "ewise_mult"
         other = self._expect_type(
-            other, (Matrix, TransposedMatrix), within=method_name, argname="other"
+            other, (Matrix, TransposedMatrix), within=method_name, argname="other", op=op
         )
         op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
         # Per the spec, op may be a semiring, but this is weird, so don't.
@@ -466,7 +487,7 @@ class Matrix(BaseType):
         Default op is semiring.plus_times
         """
         method_name = "mxv"
-        other = self._expect_type(other, Vector, within=method_name, argname="other")
+        other = self._expect_type(other, Vector, within=method_name, argname="other", op=op)
         op = get_typed_op(op, self.dtype, other.dtype, kind="semiring")
         self._expect_op(op, "Semiring", within=method_name, argname="op")
         expr = VectorExpression(
@@ -489,7 +510,7 @@ class Matrix(BaseType):
         """
         method_name = "mxm"
         other = self._expect_type(
-            other, (Matrix, TransposedMatrix), within=method_name, argname="other"
+            other, (Matrix, TransposedMatrix), within=method_name, argname="other", op=op
         )
         op = get_typed_op(op, self.dtype, other.dtype, kind="semiring")
         self._expect_op(op, "Semiring", within=method_name, argname="op")
@@ -515,7 +536,7 @@ class Matrix(BaseType):
         """
         method_name = "kronecker"
         other = self._expect_type(
-            other, (Matrix, TransposedMatrix), within=method_name, argname="other"
+            other, (Matrix, TransposedMatrix), within=method_name, argname="other", op=op
         )
         op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
         # Per the spec, op may be a semiring, but this is weird, so don't.
@@ -565,6 +586,7 @@ class Matrix(BaseType):
                         within=method_name,
                         keyword_name="left",
                         extra_message="Literal scalars also accepted.",
+                        op=op,
                     )
             op = get_typed_op(op, left.dtype, self.dtype, is_left_scalar=True, kind="binary")
             if op.opclass == "Monoid":
@@ -591,6 +613,7 @@ class Matrix(BaseType):
                         within=method_name,
                         keyword_name="right",
                         extra_message="Literal scalars also accepted.",
+                        op=op,
                     )
             op = get_typed_op(op, self.dtype, right.dtype, is_right_scalar=True, kind="binary")
             if op.opclass == "Monoid":
@@ -823,10 +846,10 @@ class Matrix(BaseType):
                         # Upcast v to a Matrix and use Matrix_assign
                         rows = _CArray([rows.scalar.value])
                         rowscalar = _CScalar(1)
-                        delayed = MatrixExpression(
+                        expr = MatrixExpression(
                             method_name,
                             "GrB_Matrix_assign",
-                            [_VectorAsMatrix(value), rows, rowscalar, cols, colscalar],
+                            [value._as_matrix(), rows, rowscalar, cols, colscalar],
                             expr_repr="[[{2} rows], [{4} cols]] = {0.name}",
                             nrows=self._nrows,
                             ncols=self._ncols,
@@ -844,7 +867,7 @@ class Matrix(BaseType):
                         # C[i, J] << v
                         cfunc_name = "GrB_Row_assign"
                         expr_repr = "[{1}, [{3} cols]] = {0.name}"
-                    delayed = MatrixExpression(
+                    expr = MatrixExpression(
                         method_name,
                         cfunc_name,
                         [value, rows, cols, colscalar],
@@ -867,10 +890,10 @@ class Matrix(BaseType):
                         # Upcast v to a Matrix and use Matrix_assign
                         cols = _CArray([cols.scalar.value])
                         colscalar = _CScalar(1)
-                        delayed = MatrixExpression(
+                        expr = MatrixExpression(
                             method_name,
                             "GrB_Matrix_assign",
-                            [_VectorAsMatrix(value), rows, rowscalar, cols, colscalar],
+                            [value._as_matrix(), rows, rowscalar, cols, colscalar],
                             expr_repr="[[{2} rows], [{4} cols]] = {0.name}",
                             nrows=self._nrows,
                             ncols=self._ncols,
@@ -887,7 +910,7 @@ class Matrix(BaseType):
                         # C[I, j] << v
                         cfunc_name = "GrB_Col_assign"
                         expr_repr = "[{1}, [{3} cols]] = {0.name}"
-                    delayed = MatrixExpression(
+                    expr = MatrixExpression(
                         method_name,
                         cfunc_name,
                         [value, rows, rowscalar, cols],
@@ -947,7 +970,7 @@ class Matrix(BaseType):
                 # C(M)[I, J] << A
                 cfunc_name = "GrB_Matrix_assign"
                 expr_repr = "[[{2} rows], [{4} cols]] = {0.name}"
-            delayed = MatrixExpression(
+            expr = MatrixExpression(
                 method_name,
                 cfunc_name,
                 [value, rows, rowscalar, cols, colscalar],
@@ -991,7 +1014,7 @@ class Matrix(BaseType):
                     value_vector << value
 
                     # Row-only selection
-                    delayed = MatrixExpression(
+                    expr = MatrixExpression(
                         method_name,
                         cfunc_name,
                         [value_vector, rows, cols, colscalar],
@@ -1015,7 +1038,7 @@ class Matrix(BaseType):
                     value_vector << value
 
                     # Column-only selection
-                    delayed = MatrixExpression(
+                    expr = MatrixExpression(
                         method_name,
                         cfunc_name,
                         [value_vector, rows, rowscalar, cols],
@@ -1066,7 +1089,7 @@ class Matrix(BaseType):
                         colscalar = _CScalar(1)
                     cfunc_name = f"GrB_Matrix_assign_{value.dtype}"
                     expr_repr = "[[{2} rows], [{4} cols]] = {0}"
-                delayed = MatrixExpression(
+                expr = MatrixExpression(
                     method_name,
                     cfunc_name,
                     [_CScalar(value), rows, rowscalar, cols, colscalar],
@@ -1075,7 +1098,7 @@ class Matrix(BaseType):
                     ncols=self._ncols,
                     dtype=self.dtype,
                 )
-        return delayed
+        return expr
 
     def _delete_element(self, resolved_indexes):
         rowidx, colidx = resolved_indexes.indices
@@ -1129,6 +1152,7 @@ Matrix.ss = class_property(Matrix.ss, ss)
 
 class MatrixExpression(BaseExpression):
     __slots__ = "_ncols", "_nrows"
+    ndim = 2
     output_type = Matrix
     _is_transposed = False
 
@@ -1246,6 +1270,7 @@ class MatrixExpression(BaseExpression):
 
 class TransposedMatrix:
     __slots__ = "_matrix", "_ncols", "_nrows", "__weakref__"
+    ndim = 2
     _is_scalar = False
     _is_transposed = True
 
@@ -1259,10 +1284,10 @@ class TransposedMatrix:
 
         return format_matrix(self)
 
-    def _repr_html_(self):
+    def _repr_html_(self, collapse=False):
         from .formatting import format_matrix_html
 
-        return format_matrix_html(self)
+        return format_matrix_html(self, collapse=collapse)
 
     def new(self, dtype=None, *, mask=None, name=None):
         if dtype is None:
