@@ -3,17 +3,22 @@ import itertools
 import re
 from collections.abc import Mapping
 from functools import lru_cache
+from operator import getitem
 from types import FunctionType, ModuleType
 
 import numba
 import numpy as np
 
-from . import binary, config, ffi, lib, monoid, op, semiring, unary
+from . import config, ffi, lib
 from .dtypes import INT8, _sample_values, _supports_complex, lookup_dtype, unify
 from .exceptions import UdfParseError, check_status_carg
 from .expr import InfixExprBase
 from .utils import libget, output_type
 
+_STANDARD_OPERATOR_NAMES = set()
+
+from . import binary, monoid, op, semiring, unary  # noqa isort:skip
+
 ffi_new = ffi.new
 UNKNOWN_OPCLASS = "UnknownOpClass"
 
@@ -22,10 +27,22 @@ def _normalize_type(type_):
     return lookup_dtype(type_).name
 
 
+def _hasop(module, name):
+    return name in module.__dict__ or name in module._delayed
+
+
 class OpPath:
     def __init__(self, parent, name):
         self._parent = parent
         self._name = name
+        self._delayed = {}
+        self._delayed_commutes_to = {}
+
+    def __getattr__(self, key):
+        if key in self._delayed:
+            func, kwargs = self._delayed.pop(key)
+            return func(**kwargs)
+        self.__getattribute__(key)  # raises
 
 
 def _call_op(op, left, right=None, **kwargs):
@@ -84,6 +101,9 @@ class TypedOpBase:
     def _carg(self):
         return self.gb_obj
 
+    def __reduce__(self):
+        return (getitem, (self.parent, self.type))
+
 
 class TypedBuiltinUnaryOp(TypedOpBase):
     __slots__ = ()
@@ -277,6 +297,10 @@ class TypedUserSemiring(TypedOpBase):
     __call__ = TypedBuiltinSemiring.__call__
 
 
+def _deserialize_parameterized(parameterized_op, args, kwargs):
+    return parameterized_op(*args, **kwargs)
+
+
 class ParameterizedUdf:
     __slots__ = "name", "__call__", "_anonymous", "__weakref__"
 
@@ -303,8 +327,24 @@ class ParameterizedUnaryOp(ParameterizedUdf):
 
     def _call(self, *args, **kwargs):
         unary = self.func(*args, **kwargs)
+        unary._parameterized_info = (self, args, kwargs)
         return UnaryOp.register_anonymous(unary, self.name)
 
+    def __reduce__(self):
+        name = f"unary.{self.name}"
+        if not self._anonymous and name in _STANDARD_OPERATOR_NAMES:  # pragma: no cover
+            return name
+        return (self._deserialize, (self.name, self.func, self._anonymous))
+
+    @staticmethod
+    def _deserialize(name, func, anonymous):
+        if anonymous:
+            return UnaryOp.register_anonymous(func, name, parameterized=True)
+        rv = UnaryOp._find(name)
+        if rv is not None:
+            return rv
+        return UnaryOp.register_new(name, func, parameterized=True)
+
 
 class ParameterizedBinaryOp(ParameterizedUdf):
     __slots__ = "func", "__signature__", "_monoid", "_cached_call", "commutes_to"
@@ -323,6 +363,7 @@ class ParameterizedBinaryOp(ParameterizedUdf):
 
     def _call_to_cache(self, *args, **kwargs):
         binary = self.func(*args, **kwargs)
+        binary._parameterized_info = (self, args, kwargs)
         return BinaryOp.register_anonymous(binary, self.name)
 
     def _call(self, *args, **kwargs):
@@ -349,6 +390,21 @@ class ParameterizedBinaryOp(ParameterizedUdf):
 
     is_commutative = TypedBuiltinBinaryOp.is_commutative
 
+    def __reduce__(self):
+        name = f"binary.{self.name}"
+        if not self._anonymous and name in _STANDARD_OPERATOR_NAMES:
+            return name
+        return (self._deserialize, (self.name, self.func, self._anonymous))
+
+    @staticmethod
+    def _deserialize(name, func, anonymous):
+        if anonymous:
+            return BinaryOp.register_anonymous(func, name, parameterized=True)
+        rv = BinaryOp._find(name)
+        if rv is not None:
+            return rv
+        return BinaryOp.register_new(name, func, parameterized=True)
+
 
 class ParameterizedMonoid(ParameterizedUdf):
     __slots__ = "binaryop", "identity", "__signature__"
@@ -387,6 +443,21 @@ class ParameterizedMonoid(ParameterizedUdf):
 
     commutes_to = TypedBuiltinMonoid.commutes_to
 
+    def __reduce__(self):
+        name = f"monoid.{self.name}"
+        if not self._anonymous and name in _STANDARD_OPERATOR_NAMES:  # pragma: no cover
+            return name
+        return (self._deserialize, (self.name, self.binaryop, self.identity, self._anonymous))
+
+    @staticmethod
+    def _deserialize(name, binaryop, identity, anonymous):
+        if anonymous:
+            return Monoid.register_anonymous(binaryop, identity, name)
+        rv = Monoid._find(name)
+        if rv is not None:
+            return rv
+        return Monoid.register_new(name, binaryop, identity)
+
 
 class ParameterizedSemiring(ParameterizedUdf):
     __slots__ = "monoid", "binaryop", "__signature__"
@@ -429,6 +500,24 @@ class ParameterizedSemiring(ParameterizedUdf):
     commutes_to = TypedBuiltinSemiring.commutes_to
     is_commutative = TypedBuiltinSemiring.is_commutative
 
+    def __reduce__(self):
+        name = f"semiring.{self.name}"
+        if not self._anonymous and name in _STANDARD_OPERATOR_NAMES:  # pragma: no cover
+            return name
+        return (self._deserialize, (self.name, self.monoid, self.binaryop, self._anonymous))
+
+    @staticmethod
+    def _deserialize(name, monoid, binaryop, anonymous):
+        if anonymous:
+            return Semiring.register_anonymous(monoid, binaryop, name)
+        rv = Semiring._find(name)
+        if rv is not None:
+            return rv
+        return Semiring.register_new(name, monoid, binaryop)
+
+
+_VARNAMES = tuple(x for x in dir(lib) if x[0] != "_")
+
 
 class OpBase:
     __slots__ = "name", "_typed_ops", "types", "coercions", "_anonymous", "__weakref__"
@@ -485,8 +574,7 @@ class OpBase:
                     raise AttributeError(
                         f"{modname} is already defined. Cannot use as a nested path."
                     )
-            # Can't use `hasattr` here, b/c we use `__getattr__` in numpy namespaces
-            if strict and funcname in module.__dict__:
+            if strict and _hasop(module, funcname):
                 raise AttributeError(f"{path}.{funcname} is already defined")
         return module, funcname
 
@@ -508,7 +596,6 @@ class OpBase:
         delete_exact = cls._parse_config.get("delete_exact", None)
         num_underscores = cls._parse_config["num_underscores"]
 
-        varnames = tuple(x for x in dir(lib) if x[0] != "_")
         for re_str, return_prefix in (
             ("re_exprs", None),
             ("re_exprs_return_bool", "BOOL"),
@@ -520,7 +607,7 @@ class OpBase:
             if "complex" in re_str and not _supports_complex:  # pragma: no cover
                 continue
             for r in reversed(cls._parse_config[re_str]):
-                for varname in varnames:
+                for varname in _VARNAMES:
                     m = r.match(varname)
                     if m:
                         # Parse function into name and datatype
@@ -537,6 +624,7 @@ class OpBase:
                         if not hasattr(cls._module, name):
                             obj = cls(name)
                             setattr(cls._module, name, obj)
+                            _STANDARD_OPERATOR_NAMES.add(f"{cls._modname}.{name}")
                             if not hasattr(op, name):
                                 setattr(op, name, obj)
                         else:
@@ -562,11 +650,17 @@ class OpBase:
                             obj, name, type_, return_type, gb_obj, gb_name
                         )
                         obj._add(builtin_op)
-        cls._initialized = True
+
+    @classmethod
+    def _deserialize(cls, name, *args):
+        rv = cls._find(name)
+        if rv is not None:
+            return rv  # Should we verify this is what the user expects?
+        return cls.register_new(name, *args)
 
 
 class UnaryOp(OpBase):
-    __slots__ = ()
+    __slots__ = "_func"
     _module = unary
     _modname = "unary"
     _typed_class = TypedBuiltinUnaryOp
@@ -604,7 +698,7 @@ class UnaryOp(OpBase):
         if name is None:
             name = getattr(func, "__name__", "<anonymous_unary>")
         success = False
-        new_type_obj = cls(name, anonymous=anonymous)
+        new_type_obj = cls(name, func, anonymous=anonymous)
         return_types = {}
         nt = numba.types
         for type_, sample_val in _sample_values.items():
@@ -695,18 +789,30 @@ class UnaryOp(OpBase):
         return cls._build(name, func, anonymous=True)
 
     @classmethod
-    def register_new(cls, name, func, *, parameterized=False):
+    def register_new(cls, name, func, *, parameterized=False, lazy=False):
         module, funcname = cls._remove_nesting(name)
-        if parameterized:
+        if lazy:
+            module._delayed[funcname] = (
+                cls.register_new,
+                {"name": name, "func": func, "parameterized": parameterized},
+            )
+        elif parameterized:
             unary_op = ParameterizedUnaryOp(name, func)
+            setattr(module, funcname, unary_op)
         else:
             unary_op = cls._build(name, func)
-        setattr(module, funcname, unary_op)
-        # Also save it to `grblas.op` if not yet defined
-        module, funcname = cls._remove_nesting(name, module=op, modname="op", strict=False)
-        if not hasattr(module, funcname):
             setattr(module, funcname, unary_op)
-        return unary_op
+        # Also save it to `grblas.op` if not yet defined
+        opmodule, funcname = cls._remove_nesting(name, module=op, modname="op", strict=False)
+        if not _hasop(opmodule, funcname):
+            if lazy:
+                opmodule._delayed[funcname] = module
+            else:
+                setattr(opmodule, funcname, unary_op)
+        if not cls._initialized:  # pragma: no cover
+            _STANDARD_OPERATOR_NAMES.add(f"{cls._modname}.{name}")
+        if not lazy:
+            return unary_op
 
     @classmethod
     def _initialize(cls):
@@ -746,12 +852,50 @@ class UnaryOp(OpBase):
                             op.types[dtype] = output_type
                             op._typed_ops[dtype] = typed_op
                             op.coercions[dtype] = target_type
+        cls._initialized = True
+
+    def __init__(self, name, func=None, *, anonymous=False):
+        super().__init__(name, anonymous=anonymous)
+        self._func = func
+
+    def __reduce__(self):
+        if self._anonymous:
+            if hasattr(self._func, "_parameterized_info"):
+                return (_deserialize_parameterized, self._func._parameterized_info)
+            return (self.register_anonymous, (self._func, self.name))
+        name = f"unary.{self.name}"
+        if name in _STANDARD_OPERATOR_NAMES:
+            return name
+        return (self._deserialize, (self.name, self._func))
 
     __call__ = TypedBuiltinUnaryOp.__call__
 
 
+def _floordiv(x, y):
+    return x // y  # cast to integer
+
+
+def _rfloordiv(x, y):
+    return y // x  # cast to integer
+
+
+def _absfirst(x, y):
+    return abs(x)
+
+
+def _abssecond(x, y):
+    return abs(y)
+
+
+def _isclose(rel_tol=1e-7, abs_tol=0.0):
+    def inner(x, y):
+        return x == y or abs(x - y) <= max(rel_tol * max(abs(x), abs(y)), abs_tol)
+
+    return inner
+
+
 class BinaryOp(OpBase):
-    __slots__ = "_monoid", "commutes_to", "_semiring_commutes_to"
+    __slots__ = "_monoid", "commutes_to", "_semiring_commutes_to", "_func"
     _module = binary
     _modname = "binary"
     _typed_class = TypedBuiltinBinaryOp
@@ -808,8 +952,8 @@ class BinaryOp(OpBase):
         "firstj": "secondj",
         "firstj1": "secondj1",
         # custom
-        "absfirst": "abssecond",
-        "floordiv": "rfloordiv",
+        # "absfirst": "abssecond",  # handled in grblas.binary
+        # "floordiv": "rfloordiv",
         "truediv": "rtruediv",
     }
     _commutes_to_in_semiring = {
@@ -851,7 +995,7 @@ class BinaryOp(OpBase):
         if name is None:
             name = getattr(func, "__name__", "<anonymous_binary>")
         success = False
-        new_type_obj = cls(name, anonymous=anonymous)
+        new_type_obj = cls(name, func, anonymous=anonymous)
         return_types = {}
         nt = numba.types
         for type_, sample_val in _sample_values.items():
@@ -948,18 +1092,30 @@ class BinaryOp(OpBase):
         return cls._build(name, func, anonymous=True)
 
     @classmethod
-    def register_new(cls, name, func, *, parameterized=False):
+    def register_new(cls, name, func, *, parameterized=False, lazy=False):
         module, funcname = cls._remove_nesting(name)
-        if parameterized:
+        if lazy:
+            module._delayed[funcname] = (
+                cls.register_new,
+                {"name": name, "func": func, "parameterized": parameterized},
+            )
+        elif parameterized:
             binary_op = ParameterizedBinaryOp(name, func)
+            setattr(module, funcname, binary_op)
         else:
             binary_op = cls._build(name, func)
-        setattr(module, funcname, binary_op)
-        # Also save it to `grblas.op` if not yet defined
-        module, funcname = cls._remove_nesting(name, module=op, modname="op", strict=False)
-        if not hasattr(module, funcname):
             setattr(module, funcname, binary_op)
-        return binary_op
+        # Also save it to `grblas.op` if not yet defined
+        opmodule, funcname = cls._remove_nesting(name, module=op, modname="op", strict=False)
+        if not _hasop(opmodule, funcname):
+            if lazy:
+                opmodule._delayed[funcname] = module
+            else:
+                setattr(opmodule, funcname, binary_op)
+        if not cls._initialized:
+            _STANDARD_OPERATOR_NAMES.add(f"{cls._modname}.{name}")
+        if not lazy:
+            return binary_op
 
     @classmethod
     def _initialize(cls):
@@ -997,20 +1153,14 @@ class BinaryOp(OpBase):
                 new_op._add(cur_op)
         # Add floordiv
         # cdiv truncates towards 0, while floordiv truncates towards -inf
-        BinaryOp.register_new("floordiv", lambda x, y: x // y)  # cast to integer
-        BinaryOp.register_new("rfloordiv", lambda x, y: y // x)  # cast to integer
+        BinaryOp.register_new("floordiv", _floordiv, lazy=True)  # cast to integer
+        BinaryOp.register_new("rfloordiv", _rfloordiv, lazy=True)  # cast to integer
 
         # For aggregators
-        BinaryOp.register_new("absfirst", lambda x, y: abs(x))
-        BinaryOp.register_new("abssecond", lambda x, y: abs(y))
+        BinaryOp.register_new("absfirst", _absfirst, lazy=True)
+        BinaryOp.register_new("abssecond", _abssecond, lazy=True)
 
-        def isclose(rel_tol=1e-7, abs_tol=0.0):
-            def inner(x, y):
-                return x == y or abs(x - y) <= max(rel_tol * max(abs(x), abs(y)), abs_tol)
-
-            return inner
-
-        BinaryOp.register_new("isclose", isclose, parameterized=True)
+        BinaryOp.register_new("isclose", _isclose, parameterized=True)
 
         # Update type information with sane coercion
         name_types = [
@@ -1080,12 +1230,24 @@ class BinaryOp(OpBase):
             right = getattr(binary, right)
             left._semiring_commutes_to = right
             right._semiring_commutes_to = left
+        cls._initialized = True
 
-    def __init__(self, name, *, anonymous=False):
+    def __init__(self, name, func=None, *, anonymous=False):
         super().__init__(name, anonymous=anonymous)
         self._monoid = None
         self.commutes_to = None
         self._semiring_commutes_to = None
+        self._func = func
+
+    def __reduce__(self):
+        if self._anonymous:
+            if hasattr(self._func, "_parameterized_info"):
+                return (_deserialize_parameterized, self._func._parameterized_info)
+            return (self.register_anonymous, (self._func, self.name))
+        name = f"binary.{self.name}"
+        if name in _STANDARD_OPERATOR_NAMES:
+            return name
+        return (self._deserialize, (self.name, self._func))
 
     __call__ = TypedBuiltinBinaryOp.__call__
     is_commutative = TypedBuiltinBinaryOp.is_commutative
@@ -1098,7 +1260,7 @@ class BinaryOp(OpBase):
 
 
 class Monoid(OpBase):
-    __slots__ = "_binaryop"
+    __slots__ = "_binaryop", "_identity"
     is_commutative = True
     _module = monoid
     _modname = "monoid"
@@ -1127,7 +1289,7 @@ class Monoid(OpBase):
             raise TypeError(f"binaryop must be a BinaryOp, not {type(binaryop)}")
         if name is None:
             name = binaryop.name
-        new_type_obj = cls(name, binaryop, anonymous=anonymous)
+        new_type_obj = cls(name, binaryop, identity, anonymous=anonymous)
         if not isinstance(identity, Mapping):
             identities = dict.fromkeys(binaryop.types, identity)
             explicit_identities = False
@@ -1161,25 +1323,46 @@ class Monoid(OpBase):
         return cls._build(name, binaryop, identity, anonymous=True)
 
     @classmethod
-    def register_new(cls, name, binaryop, identity):
+    def register_new(cls, name, binaryop, identity, *, lazy=False):
         module, funcname = cls._remove_nesting(name)
-        if type(binaryop) is ParameterizedBinaryOp:
+        if lazy:
+            module._delayed[funcname] = (
+                cls.register_new,
+                {"name": name, "binaryop": binaryop, "identity": identity},
+            )
+        elif type(binaryop) is ParameterizedBinaryOp:
             monoid = ParameterizedMonoid(name, binaryop, identity)
+            setattr(module, funcname, monoid)
         else:
             monoid = cls._build(name, binaryop, identity)
-        setattr(module, funcname, monoid)
-        # Also save it to `grblas.op` if not yet defined
-        module, funcname = cls._remove_nesting(name, module=op, modname="op", strict=False)
-        if not hasattr(module, funcname):
             setattr(module, funcname, monoid)
-        return monoid
+        # Also save it to `grblas.op` if not yet defined
+        opmodule, funcname = cls._remove_nesting(name, module=op, modname="op", strict=False)
+        if not _hasop(opmodule, funcname):
+            if lazy:
+                opmodule._delayed[funcname] = module
+            else:
+                setattr(opmodule, funcname, monoid)
+        if not cls._initialized:  # pragma: no cover
+            _STANDARD_OPERATOR_NAMES.add(f"{cls._modname}.{name}")
+        if not lazy:
+            return monoid
 
-    def __init__(self, name, binaryop=None, *, anonymous=False):
+    def __init__(self, name, binaryop=None, identity=None, *, anonymous=False):
         super().__init__(name, anonymous=anonymous)
         self._binaryop = binaryop
+        self._identity = identity
         if binaryop is not None:
             binaryop._monoid = self
 
+    def __reduce__(self):
+        if self._anonymous:
+            return (self.register_anonymous, (self._binaryop, self._identity, self.name))
+        name = f"monoid.{self.name}"
+        if name in _STANDARD_OPERATOR_NAMES:
+            return name
+        return (self._deserialize, (self.name, self._binaryop, self._identity))
+
     @property
     def binaryop(self):
         if self._binaryop is not None:
@@ -1226,6 +1409,7 @@ class Monoid(OpBase):
                 cur_op.types[dtype] = "BOOL"
                 cur_op.coercions[dtype] = "BOOL"
                 cur_op._typed_ops[dtype] = bool_op
+        cls._initialized = True
 
     commutes_to = TypedBuiltinMonoid.commutes_to
     __call__ = TypedBuiltinMonoid.__call__
@@ -1318,18 +1502,30 @@ class Semiring(OpBase):
         return cls._build(name, monoid, binaryop, anonymous=True)
 
     @classmethod
-    def register_new(cls, name, monoid, binaryop):
+    def register_new(cls, name, monoid, binaryop, *, lazy=False):
         module, funcname = cls._remove_nesting(name)
-        if type(monoid) is ParameterizedMonoid or type(binaryop) is ParameterizedBinaryOp:
+        if lazy:
+            module._delayed[funcname] = (
+                cls.register_new,
+                {"name": name, "monoid": monoid, "binaryop": binaryop},
+            )
+        elif type(monoid) is ParameterizedMonoid or type(binaryop) is ParameterizedBinaryOp:
             semiring = ParameterizedSemiring(name, monoid, binaryop)
+            setattr(module, funcname, semiring)
         else:
             semiring = cls._build(name, monoid, binaryop)
-        setattr(module, funcname, semiring)
-        # Also save it to `grblas.op` if not yet defined
-        module, funcname = cls._remove_nesting(name, module=op, modname="op", strict=False)
-        if not hasattr(module, funcname):
             setattr(module, funcname, semiring)
-        return semiring
+        # Also save it to `grblas.op` if not yet defined
+        opmodule, funcname = cls._remove_nesting(name, module=op, modname="op", strict=False)
+        if not _hasop(opmodule, funcname):
+            if lazy:
+                opmodule._delayed[funcname] = module
+            else:
+                setattr(opmodule, funcname, semiring)
+        if not cls._initialized:
+            _STANDARD_OPERATOR_NAMES.add(f"{cls._modname}.{name}")
+        if not lazy:
+            return semiring
 
     @classmethod
     def _initialize(cls):
@@ -1361,11 +1557,11 @@ class Semiring(OpBase):
         # Also add truediv (always floating point) and floordiv (truncate towards -inf)
         for orig_name, orig in div_semirings.items():
             cls.register_new(f"{orig_name[:-3]}truediv", orig.monoid, binary.truediv)
-            cls.register_new(f"{orig_name[:-3]}floordiv", orig.monoid, binary.floordiv)
+            cls.register_new(f"{orig_name[:-3]}floordiv", orig.monoid, "floordiv", lazy=True)
         # For aggregators
         cls.register_new("plus_pow", monoid.plus, binary.pow)
-        cls.register_new("plus_absfirst", monoid.plus, binary.absfirst)
-        cls.register_new("max_absfirst", monoid.max, binary.absfirst)
+        cls.register_new("plus_absfirst", monoid.plus, "absfirst", lazy=True)
+        cls.register_new("max_absfirst", monoid.max, "absfirst", lazy=True)
 
         # Update type information with sane coercion
         for lname in ("any", "eq", "land", "lor", "lxnor", "lxor"):
@@ -1464,12 +1660,21 @@ class Semiring(OpBase):
             cur_op.types["BOOL"] = target.types["BOOL"]
             cur_op._typed_ops["BOOL"] = target._typed_ops["BOOL"]
             cur_op.coercions["BOOL"] = "BOOL"
+        cls._initialized = True
 
     def __init__(self, name, monoid=None, binaryop=None, *, anonymous=False):
         super().__init__(name, anonymous=anonymous)
         self._monoid = monoid
         self._binaryop = binaryop
 
+    def __reduce__(self):
+        if self._anonymous:
+            return (self.register_anonymous, (self._monoid, self._binaryop, self.name))
+        name = f"semiring.{self.name}"
+        if name in _STANDARD_OPERATOR_NAMES:
+            return name
+        return (self._deserialize, (self.name, self._monoid, self._binaryop))
+
     @property
     def binaryop(self):
         if self._binaryop is not None:
@@ -1617,10 +1822,18 @@ def get_semiring(monoid, binaryop, name=None):
             name = canonical_name
 
         module, funcname = Semiring._remove_nesting(canonical_name, strict=False)
-        rv = module.__dict__.get(funcname)
+        rv = (
+            getattr(module, funcname)
+            if funcname in module.__dict__ or funcname in module._delayed
+            else None
+        )
         if rv is None and name != canonical_name:
             module, funcname = Semiring._remove_nesting(name, strict=False)
-            rv = module.__dict__.get(funcname)
+            rv = (
+                getattr(module, funcname)
+                if funcname in module.__dict__ or funcname in module._delayed
+                else None
+            )
         if rv is None:
             rv = Semiring.register_new(canonical_name, monoid, binaryop)
         elif rv.monoid is not monoid or rv.binaryop is not binaryop:  # pragma: no cover
@@ -1628,7 +1841,7 @@ def get_semiring(monoid, binaryop, name=None):
             rv = Semiring.register_anonymous(monoid, binaryop, name=name)
         if name != canonical_name:
             module, funcname = Semiring._remove_nesting(name, strict=False)
-            if funcname not in module.__dict__:  # pragma: no branch
+            if not _hasop(module, funcname):  # pragma: no branch
                 setattr(module, funcname, rv)
 
     if binary_type is not None:
@@ -1640,10 +1853,17 @@ def get_semiring(monoid, binaryop, name=None):
 
 
 # Now initialize all the things!
-UnaryOp._initialize()
-BinaryOp._initialize()
-Monoid._initialize()
-Semiring._initialize()
+try:
+    UnaryOp._initialize()
+    BinaryOp._initialize()
+    Monoid._initialize()
+    Semiring._initialize()
+except Exception:  # pragma: no cover
+    # Exceptions here can often get ignored by Python
+    import traceback
+
+    traceback.print_exc()
+    raise
 
 _str_to_unary = {
     "-": unary.ainv,
@@ -1660,8 +1880,8 @@ _str_to_binary = {
     "-": binary.minus,
     "*": binary.times,
     "/": binary.truediv,
-    "//": binary.floordiv,
-    "%": binary.numpy.mod,
+    "//": "floordiv",
+    "%": "numpy.mod",
     "**": binary.pow,
     "&": binary.land,
     "|": binary.lor,
@@ -1701,13 +1921,25 @@ def _from_string(string, module, mapping, example):
         )
     if base in mapping:
         op = mapping[base]
+        if type(op) is str:
+            op = mapping[base] = module.from_string(op)
     elif hasattr(module, base):
         op = getattr(module, base)
     elif hasattr(module.numpy, base):
         op = getattr(module.numpy, base)
     else:
-        name = module.__name__.split(".")[-1]
-        raise ValueError(f"Unknown {name} string: {string!r}.  Example usage: {example!r}")
+        *paths, attr = base.split(".")
+        op = None
+        cur = module
+        for path in paths:
+            cur = getattr(cur, path, None)
+            if not isinstance(cur, (OpPath, ModuleType)):
+                cur = None
+                break
+        op = getattr(cur, attr, None)
+        if op is None:
+            name = module.__name__.split(".")[-1]
+            raise ValueError(f"Unknown {name} string: {string!r}.  Example usage: {example!r}")
     if dtype:
         op = op[dtype]
     return op
@@ -1743,9 +1975,24 @@ def semiring_from_string(string):
     return get_semiring(cur_monoid, cur_binary)
 
 
+def op_from_string(string):
+    for func in [
+        unary_from_string,
+        binary_from_string,
+        monoid_from_string,
+        semiring_from_string,
+    ]:
+        try:
+            return func(string)
+        except Exception:
+            pass
+    raise ValueError(f"Unknown op string: {string!r}.  Example usage: 'abs[int]'")
+
+
 unary.from_string = unary_from_string
 binary.from_string = binary_from_string
 monoid.from_string = monoid_from_string
 semiring.from_string = semiring_from_string
+op.from_string = op_from_string
 
 from .agg import Aggregator, TypedAggregator  # noqa isort:skip
