@@ -19,6 +19,7 @@ class Scalar(BaseType):
     """
 
     __slots__ = "_is_empty"
+    ndim = 0
     shape = ()
     _is_scalar = True
     _name_counter = itertools.count()
@@ -34,7 +35,7 @@ class Scalar(BaseType):
 
         return format_scalar(self)
 
-    def _repr_html_(self):
+    def _repr_html_(self, collapse=False):
         from .formatting import format_scalar_html
 
         return format_scalar_html(self)
@@ -269,6 +270,7 @@ class Scalar(BaseType):
 class ScalarExpression(BaseExpression):
     __slots__ = ()
     output_type = Scalar
+    ndim = 0
     shape = ()
     _is_scalar = True
 
@@ -341,7 +343,7 @@ class _CScalar:
     def __repr__(self):
         return repr(self.scalar.value)
 
-    def _repr_html_(self):
+    def _repr_html_(self, collapse=False):
         return self.scalar._repr_html_()
 
     @property
