@@ -3,27 +3,25 @@ import itertools
 import numpy as np
 import pytest
 
-import grblas
-from grblas import (
-    Matrix,
-    Vector,
-    agg,
-    binary,
-    dtypes,
-    exceptions,
-    lib,
-    monoid,
-    operator,
-    semiring,
-    unary,
-)
+import grblas as gb
+from grblas import agg, binary, dtypes, lib, monoid, op, operator, semiring, unary
+from grblas.exceptions import DomainMismatch, UdfParseError
 from grblas.operator import BinaryOp, Monoid, Semiring, UnaryOp, get_semiring
 
+from grblas import Matrix, Vector  # isort:skip
+
 
 def orig_types(op):
     return op.types.keys() - op.coercions.keys()
 
 
+def test_operator_initialized():
+    assert operator.UnaryOp._initialized
+    assert operator.BinaryOp._initialized
+    assert operator.Monoid._initialized
+    assert operator.Semiring._initialized
+
+
 def test_op_repr():
     assert repr(unary.ainv) == "unary.ainv"
     assert repr(binary.plus) == "binary.plus"
@@ -141,7 +139,7 @@ def test_unaryop_udf():
     with pytest.raises(TypeError, match="UDF argument must be a function"):
         UnaryOp.register_new("bad", object())
     assert not hasattr(unary, "bad")
-    with pytest.raises(exceptions.UdfParseError, match="Unable to parse function using Numba"):
+    with pytest.raises(UdfParseError, match="Unable to parse function using Numba"):
         UnaryOp.register_new("bad", lambda x: v)
 
 
@@ -215,7 +213,7 @@ def test_binaryop_parameterized():
     with pytest.raises(TypeError, match="UDF argument must be a function"):
         BinaryOp.register_new("bad", object())
     assert not hasattr(binary, "bad")
-    with pytest.raises(exceptions.UdfParseError, match="Unable to parse function using Numba"):
+    with pytest.raises(UdfParseError, match="Unable to parse function using Numba"):
         BinaryOp.register_new("bad", lambda x, y: v)
 
     def my_add(x, y):
@@ -285,7 +283,7 @@ def test_monoid_parameterized():
     fv = v.apply(unary.identity).new(dtype=dtypes.FP64)
     bin_op = BinaryOp.register_anonymous(logaddexp, parameterized=True)
     Monoid.register_new("_user_defined_monoid", bin_op, -np.inf)
-    monoid = grblas.monoid._user_defined_monoid
+    monoid = gb.monoid._user_defined_monoid
     fv2 = fv.ewise_mult(fv, monoid(2)).new()
     plus1 = UnaryOp.register_anonymous(lambda x: x + 1)
     expected = fv.apply(plus1).new()
@@ -517,9 +515,9 @@ def test_monoid_udf():
     result = Vector.from_values([0, 1, 2, 3], [4, 2, 3, 4], dtype=dtypes.INT32)
     assert w.isequal(result)
 
-    with pytest.raises(exceptions.DomainMismatch):
+    with pytest.raises(DomainMismatch):
         Monoid.register_anonymous(binary.plus_plus_one, {"BOOL": True})
-    with pytest.raises(exceptions.DomainMismatch):
+    with pytest.raises(DomainMismatch):
         Monoid.register_anonymous(binary.plus_plus_one, {"BOOL": -1})
 
 
@@ -591,7 +589,7 @@ def test_nested_names():
 
     UnaryOp.register_new("incrementers.plus_four", plus_four)
     assert hasattr(unary.incrementers, "plus_four")
-    assert hasattr(grblas.op.incrementers, "plus_four")  # Also save it to `grblas.op`!
+    assert hasattr(op.incrementers, "plus_four")  # Also save it to `grblas.op`!
     v << v.apply(unary.incrementers.plus_four)  # this is in addition to the plus_three earlier
     result2 = Vector.from_values([0, 1, 3], [8, 9, 3], dtype=dtypes.INT32)
     assert v.isequal(result2), v
@@ -609,8 +607,6 @@ def test_nested_names():
 
 @pytest.mark.slow
 def test_op_namespace():
-    from grblas import op
-
     assert op.abs is unary.abs
     assert op.minus is binary.minus
     assert op.plus is binary.plus
@@ -628,6 +624,9 @@ def test_op_namespace():
     ):
         op.numpy.bad_attr
 
+    # Make sure all have been initialized so `vars` below works
+    for key in list(op._delayed):  # pragma: no cover
+        getattr(op, key)
     opnames = {
         key
         for key, val in vars(op).items()
@@ -653,11 +652,11 @@ def test_op_namespace():
         for key, val in vars(semiring).items()
         if isinstance(val, (operator.OpBase, operator.ParameterizedUdf))
     }
-    assert len(unarynames - opnames) == 0
-    assert len(binarynames - opnames) == 0
-    assert len(monoidnames - opnames) == 0
-    assert len(semiringnames - opnames) == 0
-    assert len(opnames - (unarynames | binarynames | monoidnames | semiringnames)) == 0
+    assert not unarynames - opnames, unarynames - opnames
+    assert not binarynames - opnames, binarynames - opnames
+    assert not monoidnames - opnames, monoidnames - opnames
+    assert not semiringnames - opnames, semiringnames - opnames
+    assert not opnames - (unarynames | binarynames | monoidnames | semiringnames)
 
 
 @pytest.mark.slow
@@ -770,8 +769,8 @@ def test_binaryop_superset_monoids():
     monoid_names = {x for x in dir(monoid) if not x.startswith("_")}
     binary_names = {x for x in dir(binary) if not x.startswith("_")}
     diff = monoid_names - binary_names
-    assert len(diff) == 0
-    assert len(set(dir(monoid.numpy)) - set(dir(binary.numpy))) == 0
+    assert not diff
+    assert not set(dir(monoid.numpy)) - set(dir(binary.numpy))
 
 
 def test_div_semirings():
@@ -909,6 +908,8 @@ def test_from_string():
     assert binary.from_string("+") is binary.plus
     assert binary.from_string("-[int]") is binary.minus[int]
     assert binary.from_string("true_divide") is binary.numpy.true_divide
+    assert binary.from_string("//") is binary.floordiv
+    assert binary.from_string("%") is binary.numpy.mod
     assert monoid.from_string("*[FP64]") is monoid.times["FP64"]
     assert semiring.from_string("min.plus") is semiring.min_plus
     assert semiring.from_string("min.+") is semiring.min_plus
@@ -930,3 +931,50 @@ def test_from_string():
         assert semiring.from_string("badname")
     with pytest.raises(ValueError, match="Bad semiring string"):
         semiring.from_string("min.plus.times")
+
+    assert op.from_string("-") is unary.ainv
+    assert op.from_string("+") is binary.plus
+    assert op.from_string("min.plus") is semiring.min_plus
+    with pytest.raises(ValueError, match="Unknown op string"):
+        op.from_string("min.plus.times")
+
+
+def test_lazy_op():
+    UnaryOp.register_new("lazy", lambda x: x, lazy=True)
+    assert isinstance(op.lazy, UnaryOp)
+    assert isinstance(unary.lazy, UnaryOp)
+    BinaryOp.register_new("lazy", lambda x, y: x + y, lazy=True)
+    Monoid.register_new("lazy", "lazy", 0, lazy=True)
+    assert isinstance(monoid.lazy, Monoid)
+    assert isinstance(binary.lazy, BinaryOp)
+    Monoid.register_new("lazy2", binary.lazy, 0, lazy=True)
+    assert isinstance(op.lazy2, Monoid)
+    assert isinstance(monoid.lazy2, Monoid)
+    Semiring.register_new("lazy", "lazy", "lazy", lazy=True)
+    assert isinstance(semiring.lazy, Semiring)
+    Semiring.register_new("lazy_lazy", monoid.lazy, binary.lazy, lazy=True)
+    assert isinstance(semiring.lazy_lazy, Semiring)
+    # numpy
+    UnaryOp.register_new("numpy.lazy", lambda x: x, lazy=True)
+    assert isinstance(unary.numpy.lazy, UnaryOp)
+    BinaryOp.register_new("numpy.lazy", lambda x, y: x + y, lazy=True)
+    Monoid.register_new("numpy.lazy", "numpy.lazy", 0, lazy=True)
+    assert isinstance(monoid.numpy.lazy, Monoid)
+    assert isinstance(binary.numpy.lazy, BinaryOp)
+    Monoid.register_new("numpy.lazy2", binary.numpy.lazy, 0, lazy=True)
+    assert isinstance(operator.get_semiring(monoid.numpy.lazy2, binary.numpy.lazy), Semiring)
+    assert isinstance(op.numpy.lazy2, Monoid)
+    assert isinstance(monoid.numpy.lazy2, Monoid)
+    Semiring.register_new("numpy.lazy", "numpy.lazy", "numpy.lazy", lazy=True)
+    assert isinstance(semiring.numpy.lazy, Semiring)
+    Semiring.register_new("numpy.lazy_lazy", monoid.numpy.lazy, binary.numpy.lazy, lazy=True)
+    assert isinstance(semiring.numpy.lazy_lazy, Semiring)
+    # misc
+    UnaryOp.register_new("misc.lazy", lambda x: x, lazy=True)
+    assert isinstance(unary.misc.lazy, UnaryOp)
+    with pytest.raises(AttributeError):
+        unary.misc.bad
+    with pytest.raises(ValueError):
+        unary.from_string("misc.lazy.badpath")
+    assert op.from_string("lazy") is unary.lazy
+    assert op.from_string("numpy.lazy") is unary.numpy.lazy
