@@ -31,6 +31,7 @@ class Vector(BaseType):
     """
 
     __slots__ = "_size", "ss"
+    ndim = 1
     _name_counter = itertools.count()
 
     def __init__(self, gb_obj, dtype, *, name=None):
@@ -47,6 +48,24 @@ class Vector(BaseType):
             # it's difficult/dangerous to record the call, b/c `self.name` may not exist
             check_status(lib.GrB_Vector_free(gb_obj), self)
 
+    def _as_matrix(self):
+        """Cast this Vector to a Matrix (such as a column vector).
+
+        This is SuiteSparse-specific and may change in the future.
+        This does not copy the vector.
+        """
+        from .matrix import Matrix
+
+        rv = Matrix(
+            ffi.cast("GrB_Matrix*", self.gb_obj),
+            self.dtype,
+            parent=self,
+            name=f"(GrB_Matrix){self.name}",
+        )
+        rv._nrows = self._size
+        rv._ncols = 1
+        return rv
+
     def __repr__(self, mask=None):
         from .formatting import format_vector
         from .recorder import skip_record
@@ -54,12 +73,12 @@ class Vector(BaseType):
         with skip_record:
             return format_vector(self, mask=mask)
 
-    def _repr_html_(self, mask=None):
+    def _repr_html_(self, mask=None, collapse=False):
         from .formatting import format_vector_html
         from .recorder import skip_record
 
         with skip_record:
-            return format_vector_html(self, mask=mask)
+            return format_vector_html(self, mask=mask, collapse=collapse)
 
     def __reduce__(self):
         # SS, SuiteSparse-specific: export
@@ -86,8 +105,8 @@ class Vector(BaseType):
         resolved_indexes = IndexerResolver(self, keys)
         return AmbiguousAssignOrExtract(self, resolved_indexes)
 
-    def __setitem__(self, keys, delayed):
-        Updater(self)[keys] = delayed
+    def __setitem__(self, keys, expr):
+        Updater(self)[keys] = expr
 
     def __contains__(self, index):
         extractor = self[index]
@@ -270,7 +289,11 @@ class Vector(BaseType):
         to use by multiple threads.  Use wait to force completion of a Vector
         and make it safe to use as input parameters on multiple threads.
         """
-        call("GrB_Vector_wait", [_Pointer(self)])
+        # TODO: expose COMPLETE or MATERIALIZE options to the user
+        call(
+            "GrB_Vector_wait",
+            [self, Scalar.from_value(lib.GrB_MATERIALIZE, name="GrB_MATERIALIZE")],
+        )
 
     @classmethod
     def new(cls, dtype, size=0, *, name=None):
@@ -348,7 +371,7 @@ class Vector(BaseType):
         For these reasons, users are required to be explicit when choosing this surprising behavior.
         """
         method_name = "ewise_add"
-        other = self._expect_type(other, Vector, within=method_name, argname="other")
+        other = self._expect_type(other, Vector, within=method_name, argname="other", op=op)
         op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
         # Per the spec, op may be a semiring, but this is weird, so don't.
         if require_monoid:
@@ -380,7 +403,7 @@ class Vector(BaseType):
         Default op is binary.times
         """
         method_name = "ewise_mult"
-        other = self._expect_type(other, Vector, within=method_name, argname="other")
+        other = self._expect_type(other, Vector, within=method_name, argname="other", op=op)
         op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
         # Per the spec, op may be a semiring, but this is weird, so don't.
         self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
@@ -404,7 +427,7 @@ class Vector(BaseType):
 
         method_name = "vxm"
         other = self._expect_type(
-            other, (Matrix, TransposedMatrix), within=method_name, argname="other"
+            other, (Matrix, TransposedMatrix), within=method_name, argname="other", op=op
         )
         op = get_typed_op(op, self.dtype, other.dtype, kind="semiring")
         self._expect_op(op, "Semiring", within=method_name, argname="op")
@@ -454,6 +477,7 @@ class Vector(BaseType):
                         within=method_name,
                         keyword_name="left",
                         extra_message="Literal scalars also accepted.",
+                        op=op,
                     )
             op = get_typed_op(op, left.dtype, self.dtype, is_left_scalar=True, kind="binary")
             if op.opclass == "Monoid":
@@ -480,6 +504,7 @@ class Vector(BaseType):
                         within=method_name,
                         keyword_name="right",
                         extra_message="Literal scalars also accepted.",
+                        op=op,
                     )
             op = get_typed_op(op, self.dtype, right.dtype, is_right_scalar=True, kind="binary")
             if op.opclass == "Monoid":
@@ -535,13 +560,13 @@ class Vector(BaseType):
         *This is not a standard GraphBLAS function*
         """
         method_name = "inner"
-        other = self._expect_type(other, Vector, within=method_name, argname="other")
+        other = self._expect_type(other, Vector, within=method_name, argname="other", op=op)
         op = get_typed_op(op, self.dtype, other.dtype, kind="semiring")
         self._expect_op(op, "Semiring", within=method_name, argname="op")
         expr = ScalarExpression(
             method_name,
             "GrB_vxm",
-            [self, _VectorAsMatrix(other)],
+            [self, other._as_matrix()],
             op=op,
         )
         if self._size != other._size:
@@ -559,7 +584,7 @@ class Vector(BaseType):
         from .matrix import MatrixExpression
 
         method_name = "outer"
-        other = self._expect_type(other, Vector, within=method_name, argname="other")
+        other = self._expect_type(other, Vector, within=method_name, argname="other", op=op)
         op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
         self._expect_op(op, ("BinaryOp", "Monoid"), within=method_name, argname="op")
         if op.opclass == "Monoid":
@@ -568,7 +593,7 @@ class Vector(BaseType):
         expr = MatrixExpression(
             method_name,
             "GrB_mxm",
-            [_VectorAsMatrix(self), _VectorAsMatrix(other)],
+            [self._as_matrix(), other._as_matrix()],
             op=op,
             nrows=self._size,
             ncols=other._size,
@@ -731,6 +756,7 @@ Vector.ss = class_property(Vector.ss, ss)
 
 class VectorExpression(BaseExpression):
     __slots__ = "_size"
+    ndim = 1
     output_type = Vector
 
     def __init__(
@@ -832,31 +858,6 @@ class VectorExpression(BaseExpression):
     __ixor__ = _automethods.__ixor__
 
 
-class _VectorAsMatrix:
-    __slots__ = "vector"
-
-    def __init__(self, vector):
-        self.vector = vector
-
-    @property
-    def _carg(self):
-        # SS, SuiteSparse-specific: casting Vector to Matrix
-        return ffi.cast("GrB_Matrix*", self.vector.gb_obj)[0]
-
-    @property
-    def name(self):
-        # Showing `(GrB_Matrix)` is good for the recorder, but not for the html repr
-        return f"(GrB_Matrix){self.vector.name}"
-
-    @property
-    def _name_html(self):
-        return self.vector._name_html
-
-    @property
-    def _repr_html_(self):
-        return self.vector._repr_html_
-
-
 utils._output_types[Vector] = Vector
 utils._output_types[VectorExpression] = Vector
 
